@@ -19,7 +19,7 @@ logger = logging.getLogger(__name__)
 
 class Reservation:
 
-    def __init__(self, node: Node, provision: str = None, loop=None, monitor: Monitor = None, ignore_node_exceptions=False, enter_on=[ReserveState.ACTIVE], exit_on=[ReserveState.ERROR, ReserveState.CANCELLED], bounced=None, **params) -> None:
+    def __init__(self, node: Node, provision: str = None, loop=None, monitor: Monitor = None, ignore_node_exceptions=False, enter_on=[ReserveState.ACTIVE], exit_on=[ReserveState.ERROR, ReserveState.CANCELLED], context=None, **params) -> None:
         bergen = get_current_client()
         self._postman = bergen.getPostman()
 
@@ -32,9 +32,9 @@ class Reservation:
         self.enter_states = enter_on
         self.provision = provision
 
-        self.bounced = bounced # with_bounced allows us forward bounced checks
+        self.context = context # with_bounced allows us forward bounced checks
 
-        if self.bounced:
+        if self.context:
             assert "can_forward_bounce" in bergen.auth.scopes, "In order to use with_bounced forwarding you need to have the can_forward_bounced scope"
 
         if self.monitor:
@@ -88,7 +88,7 @@ class Reservation:
             self.log("[red]ASSIGN",f"Contract is broken and we can not assign. Exiting!")
         try:
             shrinked_args, shrinked_kwargs = await shrinkInputs(self.node, args, kwargs) if not bypass_shrink else (args, kwargs)
-            return_message = await self._postman.assign(self.reservation, shrinked_args, shrinked_kwargs=shrinked_kwargs, on_progress=self.on_progress, persist=persist, bounced=self.bounced)
+            return_message = await self._postman.assign(self.reservation, shrinked_args, shrinked_kwargs=shrinked_kwargs, on_progress=self.on_progress, persist=persist, context=self.context)
             outs = await expandOutputs(self.node, return_message.data.returns) if not bypass_expand else return_message.data.returns
             return outs
 
@@ -109,7 +109,7 @@ class Reservation:
             self.log("[red]ASSIGN",f"Contract is broken and we can not assign. Exiting!")
         try:
             shrinked_args, shrinked_kwargs = await shrinkInputs(self.node, args, kwargs) if not bypass_shrink else (args, kwargs) 
-            async for message in self._postman.assign_stream(self.reservation, shrinked_args, serialized_kwargs=shrinked_kwargs, with_progress=True, persist=persist, bounced=self.bounced):
+            async for message in self._postman.assign_stream(self.reservation, shrinked_args, serialized_kwargs=shrinked_kwargs, with_progress=True, persist=persist, context=self.context):
 
                 if isinstance(message, AssignYieldsMessage):
                     outs = await expandOutputs(self.node, message.data.returns) if not bypass_expand else message.data.returns
@@ -140,7 +140,7 @@ class Reservation:
     async def contract_worker(self):
         self.running = True
         try:
-            async for message in self._postman.reserve_stream(node_id=self.node.id, provision=self.provision, params_dict=self.params.dict(), with_progress=True, bounced=self.bounced):
+            async for message in self._postman.reserve_stream(node_id=self.node.id, provision=self.provision, params_dict=self.params.dict(), with_progress=True, context=self.context):
                 # Before here because Reserve Critical is actually an ExceptionMessage
                 #TODO: Undo this
 
