@@ -10,7 +10,6 @@ PROVISION_REQUEST = "provision_request"
 ACTIVATE_POD = "activate_pod"
 DEACTIVATE_POD ="deactivate_pod"
 
-
 # ASIGN PATH
 ASSIGN = "assign"
 BOUNCED_ASSIGN = "bounced_assign"
@@ -18,7 +17,7 @@ BOUNCED_FORWARDED_ASSIGN = "bounced_forwarded_assign"
 
 ASSIGN_DONE = "assign_done"
 ASSIGN_CANCELLED = "assign_cancelled"
-ASSIGN_PROGRES ="assign_progress"
+ASSIGN_LOG ="assign_log"
 ASSIGN_CRITICAL = "assign_fail"
 ASSIGN_YIELD =  "assign_yield"
 ASSIGN_RETURN = "assign_return"
@@ -29,7 +28,7 @@ UNASSIGN = "unassign"
 BOUNCED_UNASSIGN = "bounced_unassign"
 
 UNASSIGN_DONE = "unassign_done"
-UNASSIGN_PROGRES ="unassign_progress"
+UNASSIGN_LOG ="unassign_log"
 UNASSIGN_CRITICAL = "unassign_fail"
 
 # Reserve
@@ -38,17 +37,19 @@ BOUNCED_RESERVE = "bounced_reserve"
 BOUNCED_FORWARDED_RESERVE = "bounced_forwarded_reserve"
 
 RESERVE_DONE = "reserve_done"
-RESERVE_PROGRESS = "reserve_progress"
+RESERVE_LOG = "reserve_log"
 RESERVE_FAIL = "reserve_fail"
+RESERVE_TRANSITION = "reserve_transition"
 RESERVE_CRITICAL = "reserve_critical"
-
+RESERVE_ACTIVE = "reserve_active"
+RESERVE_WAITING = "reserve_waiting"
 
 #Unreserve
 UNRESERVE = "unreserve"
 BOUNCED_UNRESERVE = "bounced_unreserve"
 
 UNRESERVE_DONE = "unreserve_done"
-UNRESERVE_PROGRESS = "unreserve_progress"
+UNRESERVE_LOG = "unreserve_log"
 UNRESERVE_FAIL = "unreserve_fail"
 UNRESERVE_CRITICAL = "unreserve_critical"
 
@@ -58,16 +59,17 @@ PROVIDE = "provide"
 BOUNCED_PROVIDE = "bounced_provide"
 
 PROVIDE_DONE = "provide_done"
-PROVIDE_PROGRESS = "provide_progress"
+PROVIDE_LOG = "provide_log"
+PROVIDE_TRANSITION = "provide_transition"
 PROVIDE_FAIL = "provide_fail"
 PROVIDE_CRITICAL = "provide_critical"
-
 # Unprovide
 UNPROVIDE = "unprovide"
 BOUNCED_UNPROVIDE = "bounced_unprovide"
 
 UNPROVIDE_DONE = "unprovide_done"
-UNPROVIDE_PROGRESS = "unprovide_progress"
+UNPROVIDE_LOG = "unprovide_log"
 UNPROVIDE_FAIL = "unprovide_fail"
 UNPROVIDE_CRITICAL = "unprovide_critical"
+UNPROVIDE_ERROR = "unprovide_error"
 
